==> tkdeft-0.0.1-py3-none-any.whl: tkdeft/windows/fluent/button.py <==
from ..draw import DSvgDraw
from ..canvas import DCanvas
from ..drawwidget import DDrawWidget


class DButtonDraw(DSvgDraw):
    def create_roundrect(self,
                         x1, y1, x2, y2, radius, radiusy=None, temppath=None,
                         fill="transparent", outline="black", outline2="black", width=1
                         ):
        if radiusy:
            _rx = radius
            _ry = radiusy
        else:
            _rx, _ry = radius, radius
        drawing = self.create_drawing(x2 - x1, y2 - y1, temppath=temppath)
        border = drawing[1].linearGradient(start=(x1, y1), end=(x1, y2), id="DButton.Border")
        border.add_stop_color("0%", outline)
        border.add_stop_color("100%", outline2)
        drawing[1].defs.add(border)
        drawing[1].add(
            drawing[1].rect(
                (x1, y1), (x2 - x1, y2 - y1), _rx, _ry,
                fill=fill, stroke_width=width,
                stroke=f"url(#{border.get_id()})",
            )
        )
        drawing[1].save()
        return drawing[0]


class DButtonCanvas(DCanvas):
    draw = DButtonDraw

    def create_round_rectangle(self,
                               x1, y1, x2, y2, r1, r2=None, temppath=None,
                               fill="transparent", outline="black", outline2="black", width=1
                               ):
        self._img = self.svgdraw.create_roundrect(
            x1, y1, x2, y2, r1, r2, temppath=temppath,
            fill=fill, outline=outline, outline2=outline2, width=width
        )
        self._tkimg = self.svgdraw.create_tksvg_image(self._img)
        return self.create_image(x1, y1, anchor="nw", image=self._tkimg)

    create_roundrect = create_round_rectangle


class DButton(DButtonCanvas, DDrawWidget):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#ffffff",
                "border_color": "#f0f0f0",
                "border_color2": "#d6d6d6",
                "border_width": 1,
                "radius": 6,
                "text_color": "#1b1b1b",
            },

            "hover": {
                "back_color": "#fcfcfc",
                "border_color": "#f0f0f0",
                "border_color2": "#d6d6d6",
                "border_width": 1,
                "radius": 6,
                "text_color": "#1b1b1b",
            },

            "pressed": {
                "back_color": "#fdfdfd",
                "border_color": "#f0f0f0",
                "border_color2": "#f0f0f0",
                "border_width": 1,
                "radius": 6,
                "text_color": "#636363",
            }

        }
    )

    def __init__(self, *args,
                 text="",
                 width=120,
                 height=32,
                 command=None,
                 font=None,
                 **kwargs):
        super().__init__(*args, width=width, height=height, **kwargs)

        if command is None:
            def empty(): pass

            command = empty

        self.dconfigure(
            text=text,
            command=command
        )

        self.bind("<<Clicked>>", lambda event=None: self.attributes.command())

        if font is None:
            from ...utility.fonts import SegoeFont
            self.attributes.font = SegoeFont()

    def _draw(self, event=None):
        super()._draw(event)

        self.delete("all")

        if self.enter:
            if self.button1:
                _back_color = self.attributes.pressed.back_color
                _border_color = self.attributes.pressed.border_color
                _border_color2 = self.attributes.pressed.border_color2
                _border_width = self.attributes.pressed.border_width
                _radius = self.attributes.pressed.radius
                _text_color = self.attributes.pressed.text_color
            else:
                _back_color = self.attributes.hover.back_color
                _border_color = self.attributes.hover.border_color
                _border_color2 = self.attributes.hover.border_color2
                _border_width = self.attributes.hover.border_width
                _radius = self.attributes.hover.radius
                _text_color = self.attributes.hover.text_color
        else:
            _back_color = self.attributes.rest.back_color
            _border_color = self.attributes.rest.border_color
            _border_color2 = self.attributes.rest.border_color2
            _border_width = self.attributes.rest.border_width
            _radius = self.attributes.rest.radius
            _text_color = self.attributes.rest.text_color

        self.element_border = self.create_round_rectangle(
            0, 0, self.winfo_width(), self.winfo_height(), _radius, temppath=self.temppath,
            fill=_back_color, outline=_border_color, outline2=_border_color2, width=_border_width
        )

        self.element_text = self.create_text(
            self.winfo_width() / 2, self.winfo_height() / 2, anchor="center",
            fill=_text_color, text=self.attributes.text, font=self.attributes.font
        )


class DDarkButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#272727",
                "border_color": "#303030",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "hover": {
                "back_color": "#2d2d2d",
                "border_color": "#303030",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "pressed": {
                "back_color": "#212121",
                "border_color": "#2a2a2a",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#cfcfcf",
            }
        }
    )


class DAccentButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#005fb8",
                "border_color": "#146cbe",
                "border_color2": "#00396e",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "hover": {
                "back_color": "#0359a9",
                "border_color": "#1766b0",
                "border_color2": "#0f4373",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "pressed": {
                "back_color": "#005fb8",
                "border_color": "#4389ca",
                "border_color2": "#4389ca",
                "border_width": 1,
                "radius": 6,
                "text_color": "#b4cbe0",
            }
        }
    )


class DDarkAccentButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#60cdff",
                "border_color": "#6cd1ff",
                "border_color2": "#56b4df",
                "border_width": 1,
                "radius": 6,
                "text_color": "#000000",
            },

            "hover": {
                "back_color": "#5abce9",
                "border_color": "#67c1eb",
                "border_color2": "#50a5cc",
                "border_width": 1,
                "radius": 6,
                "text_color": "#000000",
            },

            "pressed": {
                "back_color": "#52a9d1",
                "border_color": "#60b0d5",
                "border_color2": "#60b0d5",
                "border_width": 1,
                "radius": 6,
                "text_color": "#295468",
            }
        }
    )

==> tkdeft-0.0.2-py3-none-any.whl: tkdeft/windows/fluent/button.py <==
from ..draw import DSvgDraw
from ..canvas import DCanvas
from ..drawwidget import DDrawWidget


class DButtonDraw(DSvgDraw):
    def create_roundrect(self,
                         x1, y1, x2, y2, radius, radiusy=None, temppath=None,
                         fill="transparent", outline="black", outline2="black", width=1
                         ):
        if radiusy:
            _rx = radius
            _ry = radiusy
        else:
            _rx, _ry = radius, radius
        drawing = self.create_drawing(x2 - x1, y2 - y1, temppath=temppath)
        border = drawing[1].linearGradient(start=(x1, y1), end=(x1, y2), id="DButton.Border")
        border.add_stop_color("0%", outline)
        border.add_stop_color("100%", outline2)
        drawing[1].defs.add(border)
        drawing[1].add(
            drawing[1].rect(
                (x1, y1), (x2 - x1, y2 - y1), _rx, _ry,
                fill=fill, stroke_width=width,
                stroke=f"url(#{border.get_id()})",
            )
        )
        drawing[1].save()
        return drawing[0]


class DButtonCanvas(DCanvas):
    draw = DButtonDraw

    def create_round_rectangle(self,
                               x1, y1, x2, y2, r1, r2=None, temppath=None,
                               fill="transparent", outline="black", outline2="black", width=1
                               ):
        self._img = self.svgdraw.create_roundrect(
            x1, y1, x2, y2, r1, r2, temppath=temppath,
            fill=fill, outline=outline, outline2=outline2, width=width
        )
        self._tkimg = self.svgdraw.create_tksvg_image(self._img)
        return self.create_image(x1, y1, anchor="nw", image=self._tkimg)

    create_roundrect = create_round_rectangle


class DButton(DButtonCanvas, DDrawWidget):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#ffffff",
                "border_color": "#f0f0f0",
                "border_color2": "#d6d6d6",
                "border_width": 1,
                "radius": 6,
                "text_color": "#1b1b1b",
            },

            "hover": {
                "back_color": "#fcfcfc",
                "border_color": "#f0f0f0",
                "border_color2": "#d6d6d6",
                "border_width": 1,
                "radius": 6,
                "text_color": "#1b1b1b",
            },

            "pressed": {
                "back_color": "#fdfdfd",
                "border_color": "#f0f0f0",
                "border_color2": "#f0f0f0",
                "border_width": 1,
                "radius": 6,
                "text_color": "#636363",
            }

        }
    )

    def __init__(self, *args,
                 text="",
                 width=120,
                 height=32,
                 command=None,
                 font=None,
                 **kwargs):
        super().__init__(*args, width=width, height=height, **kwargs)

        if command is None:
            def empty(): pass

            command = empty

        self.dconfigure(
            text=text,
            command=command
        )

        self.bind("<<Clicked>>", lambda event=None: self.focus_set(), add="+")
        self.bind("<<Clicked>>", lambda event=None: self.attributes.command(), add="+")

        if font is None:
            from ...utility.fonts import SegoeFont
            self.attributes.font = SegoeFont()

    def _draw(self, event=None):
        super()._draw(event)

        self.delete("all")

        if self.enter:
            if self.button1:
                _back_color = self.attributes.pressed.back_color
                _border_color = self.attributes.pressed.border_color
                _border_color2 = self.attributes.pressed.border_color2
                _border_width = self.attributes.pressed.border_width
                _radius = self.attributes.pressed.radius
                _text_color = self.attributes.pressed.text_color
            else:
                _back_color = self.attributes.hover.back_color
                _border_color = self.attributes.hover.border_color
                _border_color2 = self.attributes.hover.border_color2
                _border_width = self.attributes.hover.border_width
                _radius = self.attributes.hover.radius
                _text_color = self.attributes.hover.text_color
        else:
            _back_color = self.attributes.rest.back_color
            _border_color = self.attributes.rest.border_color
            _border_color2 = self.attributes.rest.border_color2
            _border_width = self.attributes.rest.border_width
            _radius = self.attributes.rest.radius
            _text_color = self.attributes.rest.text_color

        self.element_border = self.create_round_rectangle(
            0, 0, self.winfo_width(), self.winfo_height(), _radius, temppath=self.temppath,
            fill=_back_color, outline=_border_color, outline2=_border_color2, width=_border_width
        )

        self.element_text = self.create_text(
            self.winfo_width() / 2, self.winfo_height() / 2, anchor="center",
            fill=_text_color, text=self.attributes.text, font=self.attributes.font
        )


class DDarkButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#272727",
                "border_color": "#303030",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "hover": {
                "back_color": "#2d2d2d",
                "border_color": "#303030",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "pressed": {
                "back_color": "#212121",
                "border_color": "#2a2a2a",
                "border_color2": "#262626",
                "border_width": 1,
                "radius": 6,
                "text_color": "#cfcfcf",
            }
        }
    )


class DAccentButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#005fb8",
                "border_color": "#146cbe",
                "border_color2": "#00396e",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "hover": {
                "back_color": "#0359a9",
                "border_color": "#1766b0",
                "border_color2": "#0f4373",
                "border_width": 1,
                "radius": 6,
                "text_color": "#ffffff",
            },

            "pressed": {
                "back_color": "#005fb8",
                "border_color": "#4389ca",
                "border_color2": "#4389ca",
                "border_width": 1,
                "radius": 6,
                "text_color": "#b4cbe0",
            }
        }
    )


class DDarkAccentButton(DButton):
    from easydict import EasyDict

    attributes = EasyDict(
        {
            "text": "",
            "command": None,
            "font": None,

            "rest": {
                "back_color": "#60cdff",
                "border_color": "#6cd1ff",
                "border_color2": "#56b4df",
                "border_width": 1,
                "radius": 6,
                "text_color": "#000000",
            },

            "hover": {
                "back_color": "#5abce9",
                "border_color": "#67c1eb",
                "border_color2": "#50a5cc",
                "border_width": 1,
                "radius": 6,
                "text_color": "#000000",
            },

            "pressed": {
                "back_color": "#52a9d1",
                "border_color": "#60b0d5",
                "border_color2": "#60b0d5",
                "border_width": 1,
                "radius": 6,
                "text_color": "#295468",
            }
        }
    )
